@@ -14,15 +14,14 @@ def boxplot_show(df, sp_num):
 
 def histplot_show(df, sp_num):
     import matplotlib.pyplot as plt
-    import seaborn as sns
     count = 1
     for i in sp_num:
         # установка размера для графиков
         plt.figure(figsize=(20, 20))
         # построение боксплотов для каждого числового атрибута
-        plt.title(i)
         plt.subplot(5, 5, count)
-        sns.histplot(x=df[i])
+        plt.title(i)
+        plt.hist(x=df[i])
         count += 1
     plt.show()
 
@@ -34,8 +33,8 @@ def distplot_show(df, sp_num):
         # установка размера для графиков
         plt.figure(figsize=(20, 20))
         # построение боксплотов для каждого числового атрибута
-        plt.title(i)
         plt.subplot(5, 5, count)
-        sns.hist(x=df[i])
+        plt.title(i)
+        sns.distplot(x=df[i])
         count += 1
     plt.show()
